# config-comments [![NPM version](https://img.shields.io/npm/v/config-comments.svg?style=flat)](https://www.npmjs.com/package/config-comments) [![NPM downloads](https://img.shields.io/npm/dm/config-comments.svg?style=flat)](https://npmjs.org/package/config-comments) [![Build Status](https://img.shields.io/travis/jonschlinkert/config-comments.svg?style=flat)](https://travis-ci.org/jonschlinkert/config-comments)

> Parse argument commands/options from code comments using esprima and minimist.

## Install

Install with [npm](https://www.npmjs.com/):

```sh
$ npm install config-comments --save
```

## Usage

```js
var configComments = require('config-comments');

configComments('my-app', string[, options]);
```

**Example**

Assuming we have the following in file `lib.js`:

```js
// my-app: foo bar baz */
function foo(str) {
  return str;
}

function bar(str) {
  /* my-app: --disable=qux */
  return str;
}
```

We would pass `lib.js` as a string to `configComments`:

```js
var config = configComments('my-app', str);
```

**Result**

```js
{ 
  abc: { 
  _: [ 'foo', 'bar', 'baz' ], 
    disable: 'qux' 
  } 
}
```

## API

```js
configComments(keywords, string[, options]);
```

Pass _one or more keywords_ to be used _for matching comments_ that have arguments _to be parsed by minimist_.

**Params**

* `keywords` **{String|Array}**: Keyword(s) to identify comments to parse.
* `str` **{String}**: A string of valid javascript with comments to parse.
* `options` **{Object}**: Options to pass to [minimist](https://github.com/substack/minimist)
* `returns` **{Object}**: Object of parsed arguments.

**Requirements**

In `configComments` comments:

1. A keyword must be the first thing in the comment. Leading whitespace is allowed.
2. A comment should only have arguments that can be parsed by [minimist](https://github.com/substack/minimist)

## Related projects

You might also be interested in these projects:

* [lint-deps](https://www.npmjs.com/package/lint-deps): CLI tool that tells you when dependencies are missing from package.json and offers you a… [more](https://www.npmjs.com/package/lint-deps) | [homepage](https://github.com/jonschlinkert/lint-deps)
* [minimist](https://www.npmjs.com/package/minimist): parse argument options | [homepage](https://github.com/substack/minimist)

## Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/jonschlinkert/config-comments/issues/new).

## Building docs

Generate readme and API documentation with [verb][]:

```sh
$ npm install verb && npm run docs
```

Or, if [verb][] is installed globally:

```sh
$ verb
```

## Running tests

Install dev dependencies:

```sh
$ npm install -d && npm test
```

## Author

**Jon Schlinkert**

* [github/jonschlinkert](https://github.com/jonschlinkert)
* [twitter/jonschlinkert](http://twitter.com/jonschlinkert)

## License

Copyright © 2016, [Jon Schlinkert](https://github.com/jonschlinkert).
Released under the [MIT license](https://github.com/jonschlinkert/config-comments/blob/master/LICENSE).

***

_This file was generated by [verb](https://github.com/verbose/verb), v0.9.0, on April 20, 2016._